==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.j(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.aa("PercentagePriceOscillatorIndicator", () => new PercentagePriceOscillatorIndicatorDescription());
            a.z("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let PercentagePriceOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentagePriceOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
                PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
            a.ac("PercentagePriceOscillatorIndicator", () => new PercentagePriceOscillatorIndicatorDescription());
            a.ab("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
})();
